@@ -1,5 +1,5 @@
-/* $Id: sensors-interface.h 5948 2008-11-03 23:59:30Z timystery $ */
-/*  Copyright 2008 Fabian Nowak (timystery@arcor.de)
+/* $Id$ */
+/*  Copyright 2008-2010 Fabian Nowak (timystery@arcor.de)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,7 +28,9 @@
 #include "sensors-interface-common.h"
 
 /* Initializing and filling functions */
-void fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale);
+void fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale, t_sensors_dialog *sd);
+
+void free_widgets (t_sensors_dialog *ptr_sensors_dialog);
 
 void init_widgets (t_sensors_dialog *sd);
 
@@ -43,6 +45,8 @@ void add_temperature_unit_box (GtkWidget *vbox, t_sensors_dialog *sd);
 
 void add_sensors_frame (GtkWidget * notebook, t_sensors_dialog * sd);
 
+void add_update_time_box (GtkWidget * vbox, t_sensors_dialog * sd);
+
 /* Callbacks */
 //void temperature_unit_change (GtkWidget *widget, t_sensors_dialog *sd);
 
