@@ -31,7 +31,7 @@
 #include <configuration.h>
 #include <sensors-interface-common.h>
 #include <middlelayer.h>
-#include <cpu.h>
+#include <tacho.h>
 
 t_sensors *
 sensors_new (XfcePanelPlugin *plugin, gchar *plugin_config_file)
@@ -55,7 +55,7 @@ sensors_new (XfcePanelPlugin *plugin, gchar *plugin_config_file)
     /* read all sensors from libraries */
     result = initialize_all (&(sensors->chips), &(sensors->suppressmessage));
     if (result==0)
-      return NULL;
+        return NULL;
 
     sensors->num_sensorchips = sensors->chips->len;
 
@@ -103,8 +103,9 @@ sensors_init_default_values  (t_sensors *sensors, XfcePanelPlugin *plugin)
     sensors->show_labels = TRUE;
     sensors->display_values_type = DISPLAY_TEXT;
     sensors->bars_created = FALSE;
-    sensors->font_size = g_strdup("medium");
-    sensors->font_size_numerical = 2;
+    sensors->tachos_created = FALSE;
+    sensors->str_fontsize = g_strdup("medium");
+    sensors->val_fontsize = 2;
     sensors->lines_size = 3;
 
     sensors->show_colored_bars = TRUE;
@@ -126,7 +127,7 @@ sensors_init_default_values  (t_sensors *sensors, XfcePanelPlugin *plugin)
 
     sensors->show_smallspacings = FALSE;
 
-    font = NULL;
+    font = g_strdup("Sans 12");
 
     TRACE ("leaves sensors_init_default_values");
 }
