@@ -34,7 +34,6 @@
 #include <gtk/gtk.h>
 
 /* Xfce includes */
-//#include <libxfcegui4/libxfcegui4.h>
 #include <libxfce4ui/libxfce4ui.h>
 
 /* Package includes */
@@ -42,26 +41,30 @@
 #include <sensors-interface.h>
 #include <middlelayer.h>
 
+
+#define gtk_hbox_new(homogeneous, spacing) \
+        gtk_box_new(GTK_ORIENTATION_HORIZONTAL, spacing)
+
+#define gtk_vbox_new(homogeneous, spacing) \
+        gtk_box_new(GTK_ORIENTATION_VERTICAL, spacing)
+
+
 /* forward declaration to not make gcc 4.3 -Wall complain */
 void produce_min_max_values (t_chipfeature *chipfeature, t_tempscale scale, float *minval, float *maxval);
 
-/*
- * Tooltips to display for any part of this plugin
- */
-GtkTooltips *tooltips = NULL;
 
 void
 produce_min_max_values (t_chipfeature *chipfeature, t_tempscale scale, float *minval, float *maxval)
 {
-  /* assume that min and max values are read from the hddtemp/lmsensors/acpi as 
+  /* assume that min and max values are read from the hddtemp/lmsensors/acpi as
    * degree celsius per default -- very sorry for the non-metric peoples */
    if (chipfeature->class==TEMPERATURE && scale == FAHRENHEIT) {
       *minval = chipfeature->min_value * 9/5 + 32;
       *maxval = chipfeature->max_value * 9/5 + 32;
-   } else { 
+   } else {
       *minval = chipfeature->min_value;
       *maxval = chipfeature->max_value;
-   } 
+   }
 }
 
 void
@@ -71,11 +74,11 @@ fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale, t_senso
     double sensorFeature;
     t_chipfeature *chipfeature;
     gboolean *suppress;
-    GtkTreeIter *iter;
+    GtkTreeIter iter;
 #if defined(HAVE_LIBNOTIFY4) || defined(HAVE_LIBNOTIFY7)
     NotifyNotification *nn;
     GError *error = NULL;
-		gchar *icon;
+    gchar *icon;
 #endif
     gchar *summary, *body;
     float minval, maxval;
@@ -98,8 +101,6 @@ fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale, t_senso
         chipfeature = (t_chipfeature *) g_ptr_array_index (chip->chip_features, featureindex);
         g_assert (chipfeature!=NULL);
 
-        iter = g_new0 (GtkTreeIter, 1);
-
         if ( chipfeature->valid == TRUE ) {
             res = sensor_get_value
                     (chip, chipfeature->address, &sensorFeature, suppress);
@@ -122,17 +123,19 @@ fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale, t_senso
                 /* FIXME: Better popup a window or DBG message or quit plugin. */
                 break;
             }
-            g_free (chipfeature->formatted_value);
+            if (chipfeature->formatted_value != NULL)
+                g_free (chipfeature->formatted_value);
+
             chipfeature->formatted_value = g_new (gchar, 0);
             format_sensor_value (scale, chipfeature, sensorFeature,
                                  &(chipfeature->formatted_value));
-            
+
             produce_min_max_values (chipfeature, scale, &minval, &maxval);
-            
+
             chipfeature->raw_value = sensorFeature;
-            gtk_tree_store_append (model, iter, NULL);
+            gtk_tree_store_append (model, &iter, NULL);
             //if (sd->plugin_dialog)
-                gtk_tree_store_set ( model, iter,
+                gtk_tree_store_set ( model, &iter,
                                  0, chipfeature->name,
                                 1, chipfeature->formatted_value,
                                 2, chipfeature->show,
@@ -148,7 +151,6 @@ fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale, t_senso
                                 //3, maxval,
                                  //-1);
         } /* end if sensors-valid */
-        /* gtk_tree_iter_free(iter); */
     }
 
     TRACE ("leaves fill_gtkTreeStore");
@@ -171,7 +173,7 @@ add_type_box (GtkWidget * vbox, t_sensors_dialog * sd)
 
     label = gtk_label_new_with_mnemonic (_("Sensors t_ype:"));
     gtk_widget_show (label);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
     gtk_widget_show (sd->myComboBox);
@@ -183,7 +185,7 @@ add_type_box (GtkWidget * vbox, t_sensors_dialog * sd)
         gtk_combo_box_get_active(GTK_COMBO_BOX(sd->myComboBox));
 
     chip = g_ptr_array_index (sd->sensors->chips, gtk_combo_box_active);
-		DBG("index: %d, chip: %p\n", gtk_combo_box_active, chip);
+        DBG("index: %d, chip: %p\n", gtk_combo_box_active, chip);
 
     /* if (sd->sensors->num_sensorchips > 0)
         sd->mySensorLabel = gtk_label_new
@@ -197,7 +199,7 @@ add_type_box (GtkWidget * vbox, t_sensors_dialog * sd)
 
     label = gtk_label_new_with_mnemonic (_("Description:"));
     gtk_widget_show (label);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
     sd->mySensorLabel = gtk_label_new (chip->description);
@@ -216,7 +218,7 @@ add_type_box (GtkWidget * vbox, t_sensors_dialog * sd)
 void
 add_update_time_box (GtkWidget * vbox, t_sensors_dialog * sd)
 {
-    GtkWidget *spinner, *myLabel, *myBox;
+    GtkWidget *myLabel, *myBox;
     GtkAdjustment *spinner_adj;
 
     TRACE ("enters add_update_time_box");
@@ -226,19 +228,19 @@ add_update_time_box (GtkWidget * vbox, t_sensors_dialog * sd)
         sd->sensors->sensors_refresh_time, 1.0, 990.0, 1.0, 60.0, 0.0);
 
     /* creates the spinner, with no decimal places */
-    spinner = gtk_spin_button_new (spinner_adj, 10.0, 0);
+    sd->spin_button_update_time = gtk_spin_button_new (spinner_adj, 10.0, 0);
 
     myLabel = gtk_label_new_with_mnemonic ( _("U_pdate interval (seconds):"));
-    gtk_label_set_mnemonic_widget (GTK_LABEL(myLabel), spinner);
+    gtk_label_set_mnemonic_widget (GTK_LABEL(myLabel), sd->spin_button_update_time);
 
     myBox = gtk_hbox_new(FALSE, BORDER);
 
     gtk_box_pack_start (GTK_BOX (myBox), myLabel, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (myBox), spinner, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (myBox), sd->spin_button_update_time, FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), myBox, FALSE, FALSE, 0);
 
     gtk_widget_show (myLabel);
-    gtk_widget_show (spinner);
+    gtk_widget_show (sd->spin_button_update_time);
     gtk_widget_show (myBox);
 
     g_signal_connect   (G_OBJECT (spinner_adj), "value_changed",
@@ -270,11 +272,11 @@ add_sensor_settings_box ( GtkWidget * vbox, t_sensors_dialog * sd)
 
     aTreeViewColumn = gtk_tree_view_column_new_with_attributes (_("Name"),
                         myCellRendererText, "text", 0, NULL);
-                        
+
     //if (sd->plugin_dialog)
         g_signal_connect    (G_OBJECT (myCellRendererText), "edited",
                         G_CALLBACK (list_cell_text_edited), sd);
-                        
+
     gtk_tree_view_column_set_expand (aTreeViewColumn, TRUE);
     gtk_tree_view_append_column (GTK_TREE_VIEW (sd->myTreeView),
                         GTK_TREE_VIEW_COLUMN (aTreeViewColumn));
@@ -425,13 +427,80 @@ add_sensors_frame (GtkWidget * notebook, t_sensors_dialog * sd)
 }
 
 
+void
+free_widgets (t_sensors_dialog *ptr_sensors_dialog)
+{
+    int idx_chip;
+    TRACE ("enters free_widgets");
+
+    // produces gtk warning messages when closing the program:
+    //(xfce4-sensors:1471): Gtk-CRITICAL **: IA__gtk_widget_get_realized: assertion 'GTK_IS_WIDGET (widget)' failed
+    //(xfce4-sensors:1471): GLib-GObject-WARNING **: instance with invalid (NULL) class pointer
+    //(xfce4-sensors:1471): GLib-GObject-CRITICAL **: g_signal_emit_valist: assertion 'G_TYPE_CHECK_INSTANCE (instance)' failed
+    //g_object_unref (ptr_sensors_dialog->spin_button_update_time);
+
+    // TODO: unref or free: g_free(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(ptr_sensors_dialog->spin_button_update_time)));
+
+    for (idx_chip=0; idx_chip < ptr_sensors_dialog->sensors->num_sensorchips; idx_chip++)
+    {
+        GtkTreeIter iter_list_store;
+        if ( gtk_tree_model_get_iter_first(GTK_TREE_MODEL (ptr_sensors_dialog->myListStore[idx_chip]), &iter_list_store) )
+        {
+            while ( gtk_tree_store_remove ( GTK_TREE_STORE (ptr_sensors_dialog->myListStore[idx_chip]), &iter_list_store) )
+                            ;;
+        }
+        gtk_tree_store_clear(ptr_sensors_dialog->myListStore[idx_chip]);
+        g_object_unref(ptr_sensors_dialog->myListStore[idx_chip]);
+    }
+
+    // makes plugin/program crash
+    //g_ptr_array_free(ptr_sensors_dialog->sensors->chips, TRUE); /* TODO: Use middlelayer function */
+
+    g_return_if_fail (ptr_sensors_dialog != NULL);
+
+    g_return_if_fail (ptr_sensors_dialog->sensors != NULL);
+
+    /* remove timeout functions */
+    //remove_gsource (ptr_sensors_dialog->sensors->timeout_id);
+
+    /* double-click improvement */
+    //remove_gsource (ptr_sensors_dialog->sensors->doubleclick_id);
+
+    /* free structures and arrays */
+    g_ptr_array_foreach (ptr_sensors_dialog->sensors->chips, free_chip, NULL);
+
+    /* stop association to libsensors and others*/
+    sensor_interface_cleanup();
+
+    g_ptr_array_free (ptr_sensors_dialog->sensors->chips, TRUE);
+
+    g_free (ptr_sensors_dialog->sensors->plugin_config_file);
+    ptr_sensors_dialog->sensors->plugin_config_file = NULL;
+    g_free (ptr_sensors_dialog->sensors->command_name);
+    ptr_sensors_dialog->sensors->command_name = NULL;
+
+    g_free (ptr_sensors_dialog->sensors->str_fontsize);
+    ptr_sensors_dialog->sensors->str_fontsize = NULL;
+    //g_object_unref(ptr_sensors_dialog->sensors->widget_sensors);
+    //gtk_widget_destroy (ptr_sensors_dialog->sensors->widget_sensors);
+    //ptr_sensors_dialog->sensors->widget_sensors = NULL;
+    //if (ptr_sensors_dialog->sensors->widget_sensors)
+        //g_free(ptr_sensors_dialog->sensors->widget_sensors);
+
+    //g_free (ptr_sensors_dialog->sensors);
+    //ptr_sensors_dialog->sensors = NULL;
+
+    TRACE ("leaves free_widgets");
+}
+
+
 void
 init_widgets (t_sensors_dialog *sd)
 {
-    int chipindex;
-    t_chip *chip;
+    int idx_chip;
+    t_chip *ptr_chip_structure;
     t_chipfeature *chipfeature;
-    GtkTreeIter *iter;
+    GtkTreeIter iter;
     t_sensors *sensors;
     GtkTreeStore *model;
 
@@ -439,52 +508,41 @@ init_widgets (t_sensors_dialog *sd)
 
     sensors = sd->sensors;
 
-    for (chipindex=0; chipindex < sensors->num_sensorchips; chipindex++) {
-        //if (sd->plugin_dialog)
-            sd->myListStore[chipindex] = gtk_tree_store_new (6, G_TYPE_STRING,
+    for (idx_chip=0; idx_chip < sensors->num_sensorchips; idx_chip++) {
+        sd->myListStore[idx_chip] = gtk_tree_store_new (6, G_TYPE_STRING,
                         G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_STRING,
                         G_TYPE_FLOAT, G_TYPE_FLOAT);
-        //else
-            //sd->myListStore[chipindex] = gtk_tree_store_new (4, G_TYPE_STRING,
-                        //G_TYPE_STRING,
-                        //G_TYPE_FLOAT, G_TYPE_FLOAT);
 
-        chip = (t_chip *) g_ptr_array_index (sensors->chips, chipindex);
-        gtk_combo_box_append_text ( GTK_COMBO_BOX(sd->myComboBox),
-                                    chip->sensorId );
-        model = GTK_TREE_STORE (sd->myListStore[chipindex]);
+        ptr_chip_structure = (t_chip *) g_ptr_array_index (sensors->chips, idx_chip);
+        gtk_combo_box_text_append_text ( GTK_COMBO_BOX_TEXT(sd->myComboBox),
+                                    ptr_chip_structure->sensorId );
+        model = GTK_TREE_STORE (sd->myListStore[idx_chip]);
 
-        fill_gtkTreeStore (model, chip, sensors->scale,  sd);
+        fill_gtkTreeStore (model, ptr_chip_structure, sensors->scale,  sd);
     }
 
     if(sd->sensors->num_sensorchips == 0) {
-        chip = (t_chip *) g_ptr_array_index(sensors->chips, 0);
-        g_assert (chip!=NULL);
-        gtk_combo_box_append_text ( GTK_COMBO_BOX(sd->myComboBox),
-                                chip->sensorId );
-        //if (sd->plugin_dialog)
-            sd->myListStore[0] = gtk_tree_store_new (6, G_TYPE_STRING,
+        ptr_chip_structure = (t_chip *) g_ptr_array_index(sensors->chips, 0);
+        g_assert (ptr_chip_structure!=NULL);
+        gtk_combo_box_text_append_text ( GTK_COMBO_BOX_TEXT(sd->myComboBox),
+                                ptr_chip_structure->sensorId );
+
+        sd->myListStore[0] = gtk_tree_store_new (6, G_TYPE_STRING,
                                                 G_TYPE_STRING, G_TYPE_BOOLEAN,
                                                 G_TYPE_STRING, G_TYPE_DOUBLE,
                                                 G_TYPE_DOUBLE);
-        //else
-            //sd->myListStore[0] = gtk_tree_store_new (4, G_TYPE_STRING,
-                                                //G_TYPE_STRING,
-                                                //G_TYPE_DOUBLE,
-                                                //G_TYPE_DOUBLE);
-        chipfeature = (t_chipfeature *) g_ptr_array_index (chip->chip_features, 0);
+        chipfeature = (t_chipfeature *) g_ptr_array_index (ptr_chip_structure->chip_features, 0);
         g_assert (chipfeature!=NULL);
 
         g_free(chipfeature->formatted_value);
         chipfeature->formatted_value = g_strdup ("0.0");
         chipfeature->raw_value = 0.0;
 
-        iter = g_new0 (GtkTreeIter, 1);
         gtk_tree_store_append ( GTK_TREE_STORE (sd->myListStore[0]),
-                            iter, NULL);
+                            &iter, NULL);
         //if (sd->plugin_dialog)
-            gtk_tree_store_set ( GTK_TREE_STORE (sd->myListStore[0]),
-                            iter,
+        gtk_tree_store_set ( GTK_TREE_STORE (sd->myListStore[0]),
+                            &iter,
                             0, chipfeature->name,
                             1, "0.0",        /* chipfeature->formatted_value */
                             2, FALSE,        /* chipfeature->show */
@@ -509,22 +567,22 @@ init_widgets (t_sensors_dialog *sd)
 void
 reload_listbox (t_sensors_dialog *sd)
 {
-    int chipindex;
-    t_chip *chip;
-    GtkTreeStore *model;
-    t_sensors *sensors;
+    int idx_chip;
+    t_chip *ptr_chip_structure;
+    GtkTreeStore *ptr_tree_store;
+    t_sensors *ptr_sensors_structure;
 
     TRACE ("enters reload_listbox");
 
-    sensors = sd->sensors;
+    ptr_sensors_structure = sd->sensors;
 
-    for (chipindex=0; chipindex < sensors->num_sensorchips; chipindex++) {
-        chip = (t_chip *) g_ptr_array_index (sensors->chips, chipindex);
+    for (idx_chip=0; idx_chip < ptr_sensors_structure->num_sensorchips; idx_chip++) {
+        ptr_chip_structure = (t_chip *) g_ptr_array_index (ptr_sensors_structure->chips, idx_chip);
 
-        model = sd->myListStore[chipindex];
-        gtk_tree_store_clear (model);
+        ptr_tree_store = sd->myListStore[idx_chip];
+        gtk_tree_store_clear (ptr_tree_store);
 
-        fill_gtkTreeStore (model, chip, sensors->scale, sd);
+        fill_gtkTreeStore (ptr_tree_store, ptr_chip_structure, ptr_sensors_structure->scale, sd);
 
     }
     TRACE ("leaves reload_listbox");
