@@ -24,6 +24,9 @@
 
 /* Package includes */
 #include <sensors-interface-common.h>
-GtkTooltips *tooltips;
 
 GtkWidget * create_main_window (t_sensors_dialog *sd);
+
+gboolean draw_callback(GtkWidget    *widget,
+               cairo_t *cr,
+               gpointer      user_data);
